/**
 *
 */
package de.intevation.gnv.artifacts;

import java.io.FileOutputStream;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public class MeshHorizontalCrossSectionTestCase extends
                                               GNVArtifactsTestCaseBase {

    private static Logger log = Logger.getLogger(MeshHorizontalCrossSectionTestCase.class);
    
    /**
     * Constructor
     */
    public MeshHorizontalCrossSectionTestCase() {
    }

    /**
     * Constructor
     * @param name
     */
    public MeshHorizontalCrossSectionTestCase(String name) {
        super(name);
    }

    /**
     * @see de.intevation.gnv.artifacts.GNVArtifactsTestCaseBase#testArtifact()
     */
    @Override
    public void testArtifact() {
        try {
            log.debug("GNVArtifactsTestCase.testHorizontalCrossSectionMeshArtifact");
            String artefactName = "fis_modeldata";
            ArtifactFactory artifactFactory = this
                    .getArtifactFactory(artefactName);
            assertNotNull(artifactFactory);
            log.debug("HorizontalCrossSectionMesh-ArtifactFactory is available");
            Artifact artifact = artifactFactory.createArtifact(
                    "" + System.currentTimeMillis(), bootstrap.getContext());
            assertNotNull(artifact);
            log.debug("HorizontalCrossSectionMesh-Artifact is available");

            CallContext cc = createCallContext();
            Document describeDocument = this.readDocument("src/test/ressources/horizontalcrosssection_mesh/horizontalcrosssection_describe.xml");
            int steps = 6;
            
            for (int i = 1; i <= steps; i++){
                this.doNextStep(
                            artifact,
                            cc,
                            "src/test/ressources/horizontalcrosssection_mesh/" +
                            "horizontalcrosssection_step_0"+i+"_feed.xml",
                            "src/test/ressources/horizontalcrosssection_mesh/" +
                            "horizontalcrosssection_step_0"+i+"_advance.xml", 
                            describeDocument);
            }
            
            Document outputData = artifact.describe(describeDocument,cc);
            FileOutputStream fos = null;
            FileOutputStream fos2 = null;
            FileOutputStream fos3 = null;
            try {
                fos = new FileOutputStream(
                        "src/test/results/horizontalcrosssection_mesh"
                                + System.currentTimeMillis() + ".png");
                
                fos2 = new FileOutputStream(
                        "src/test/results/horizontalcrosssection_mesh"
                                + System.currentTimeMillis() + ".csv");
                fos3 = new FileOutputStream(
                        "src/test/results/horizontalcrosssection_mesh"
                                + System.currentTimeMillis() + ".odv");
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalcrosssection_mesh/" +
                                               "horizontalcrosssection_step_06_out_chart.xml"),
                              fos, cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalcrosssection_mesh/" +
                                               "horizontalcrosssection_step_06_out_csv.xml"),
                             fos2,cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalcrosssection_mesh/" +
                                               "horizontalcrosssection_step_06_out_odv.xml"),
                              fos3,cc);
            } catch (Exception e) {
                log.error(e, e);
                fail();
            } finally {
                try {
                    fos.flush();
                    fos.close();
                    fos2.flush();
                    fos2.close();
                    fos3.flush();
                    fos3.close();
                } catch (Exception e) {
                    log.error(e, e);
                }
            }
        } catch (Exception e) {
            log.error(e, e);
            fail();
        }
    }

}
